@@ -7,6 +7,7 @@ from pprint import pprint
 
 from . import compat
 from . import datasets
+from . import lang_utils
 from . import lexicon_methods
 
 # let's cheat and add a handler to the datasets logger
@@ -20,7 +21,8 @@ ch.setLevel(logging.INFO)
 LOGGER.addHandler(ch)
 LOGGER.setLevel(logging.INFO)
 
-DATASET_NAME_TO_CLASS = {
+RESOURCE_NAME_TO_CLASS = {
+    "lang_identifier": lang_utils.LangIdentifier,
     "capitol_words": datasets.CapitolWords,
     "imdb": datasets.IMDB,
     "oxford_text_archive": datasets.OxfordTextArchive,
@@ -46,10 +48,10 @@ if __name__ == "__main__":
         help="download datasets and such",
     )
     parser_download.add_argument(
-        "dataset_name",
+        "resource_name",
         type=str,
-        choices=list(DATASET_NAME_TO_CLASS.keys()),
-        help="name of dataset to download",
+        choices=list(RESOURCE_NAME_TO_CLASS.keys()),
+        help="name of resource to download",
     )
     parser_download.add_argument(
         "--data_dir",
@@ -62,7 +64,7 @@ if __name__ == "__main__":
         nargs=2,
         type=str,
         required=False,
-        help='if `dataset_name` is "reddit_comments", the [start, end) range '
+        help='if `resource_name` is "reddit_comments", the [start, end) range '
         "of dates for which comments files will be downloaded, where each "
         "item is a string formatted as YYYY-MM or YYYY-MM-DD",
     )
@@ -70,22 +72,22 @@ if __name__ == "__main__":
         "--lang",
         type=str,
         required=False,
-        help='if `dataset_name` is "wikipedia" or "wikinews", language of '
+        help='if `resource_name` is "wikipedia" or "wikinews", language of '
         "the database dump to download",
     )
     parser_download.add_argument(
         "--version",
         type=str,
         required=False,
-        help='if `dataset_name` is "wikipedia" or "wikinews", version of '
+        help='if `resource_name` is "wikipedia" or "wikinews", version of '
         "the database dump to download",
     )
     parser_download.add_argument(
         "--force",
         default=False,
         action="store_true",
-        help="if specified, force a download of `dataset_name` to `data_dir`, "
-        "whether or not that dataset already exists in this directory",
+        help="if specified, force a download of `resource_name` to `data_dir`, "
+        "whether or not that resource already exists in this directory",
     )
     # the "info" command
     parser_info = subparsers.add_parser(
@@ -94,32 +96,32 @@ if __name__ == "__main__":
         help="get basic information about datasets and such",
     )
     parser_info.add_argument(
-        "dataset_name",
+        "resource_name",
         type=str,
         nargs="?",
-        choices=list(DATASET_NAME_TO_CLASS.keys()),
-        help="name of dataset to get basic information about",
+        choices=list(RESOURCE_NAME_TO_CLASS.keys()),
+        help="name of resource to get basic information about",
     )
 
     args = vars(parser.parse_args())
 
     if args["subcommand"] == "download":
-        # do we have a `Dataset`?
-        if hasattr(DATASET_NAME_TO_CLASS[args["dataset_name"]], "download"):
-            # initialize dataset
+        # do we have a `Dataset` or similar resource class?
+        if hasattr(RESOURCE_NAME_TO_CLASS[args["resource_name"]], "download"):
+            # initialize resource
             kwargs_init = {
                 key: args[key]
                 for key in ["data_dir", "lang", "version"]
                 if args.get(key) is not None
             }
-            dataset = DATASET_NAME_TO_CLASS[args["dataset_name"]](**kwargs_init)
+            resource = RESOURCE_NAME_TO_CLASS[args["resource_name"]](**kwargs_init)
             # download data using the class method
             kwargs_dl = {
                 key: args[key]
                 for key in ["date_range", "force"]
                 if args.get(key) is not None
             }
-            dataset.download(**kwargs_dl)
+            resource.download(**kwargs_dl)
         # if not, let's assume it's a function that takes similar kwargs
         else:
             kwargs_func = {
@@ -127,20 +129,20 @@ if __name__ == "__main__":
                 for key in ["data_dir", "force"]
                 if args.get(key) is not None
             }
-            DATASET_NAME_TO_CLASS[args["dataset_name"]](**kwargs_func)
+            RESOURCE_NAME_TO_CLASS[args["resource_name"]](**kwargs_func)
 
     if args["subcommand"] == "info":
-        if args.get("dataset_name") is None:
+        if args.get("resource_name") is None:
             pprint(compat.get_config())
-        # do we have a `Dataset`?
-        elif hasattr(DATASET_NAME_TO_CLASS[args["dataset_name"]], "info"):
+        # do we have a `Dataset` or similar resource class?
+        elif hasattr(RESOURCE_NAME_TO_CLASS[args["resource_name"]], "info"):
             kwargs_init = {
                 key: args[key] for key in ["data_dir"] if args.get(key) is not None
             }
-            dataset = DATASET_NAME_TO_CLASS[args["dataset_name"]](**kwargs_init)
-            pprint(dataset.info)
+            resource = RESOURCE_NAME_TO_CLASS[args["resource_name"]](**kwargs_init)
+            pprint(resource.info)
         else:
-            LOGGER.info("no info available for dataset %s", args["dataset_name"])
+            LOGGER.info("no info available for resource %s", args["resource_name"])
 
 # finally, remove the handler that we snuck in above
 LOGGER.removeHandler(ch)
