@@ -6,6 +6,7 @@ PY2 = sys.version_info.major == 2
 is_windows = sys.platform.startswith("win")
 is_linux = sys.platform.startswith("linux")
 is_osx = sys.platform == "darwin"
+is_narrow_unicode = sys.maxunicode < 0x10ffff
 
 if PY2:
     import cPickle as pickle
@@ -15,6 +16,17 @@ if PY2:
     from urllib import unquote_plus as url_unquote_plus
     from urlparse import urljoin, urlparse
 
+    from numpy import mean as mean_
+    from numpy import median as median_
+    from numpy import std as stdev_
+
+    from math import log as _log
+
+    def log2_(x):
+        """Return the base-2 logarithm of x."""
+        return _log(x, 2)
+
+    reduce_ = reduce
     range_ = xrange
 
     unicode_ = unicode
@@ -27,6 +39,11 @@ else:
     import pickle
     from builtins import zip as zip_
     from collections.abc import Iterable
+    from functools import reduce as reduce_
+    from math import log2 as log2_
+    from statistics import mean as mean_
+    from statistics import median as median_
+    from statistics import stdev as stdev_
     from urllib.parse import unquote_plus as url_unquote_plus
     from urllib.parse import urljoin, urlparse
 
