@@ -14,11 +14,13 @@ import re
 import numpy as np
 from cytoolz import itertoolz
 from spacy.parts_of_speech import CONJ, DET, NOUN, VERB
+from spacy.matcher import Matcher
 from spacy.tokens import Span
 
 from . import compat
 from . import constants
 from . import text_utils
+from . import utils
 from .spacier import utils as spacy_utils
 
 
@@ -37,20 +39,20 @@ def words(
 
     Args:
         doc (:class:`spacy.tokens.Doc` or :class:`spacy.tokens.Span`)
-        filter_stops (bool): if True, remove stop words from word list
-        filter_punct (bool): if True, remove punctuation from word list
-        filter_nums (bool): if True, remove number-like words (e.g. 10, 'ten')
-            from word list
-        include_pos (str or Set[str]): remove words whose part-of-speech tag
-            IS NOT included in this param
-        exclude_pos (str or Set[str]): remove words whose part-of-speech tag
-            IS in the specified tags
-        min_freq (int): remove words that occur in ``doc`` fewer than
-            ``min_freq`` times
+        filter_stops (bool): If True, remove stop words from word list.
+        filter_punct (bool): If True, remove punctuation from word list.
+        filter_nums (bool): If True, remove number-like words (e.g. 10, "ten")
+            from word list.
+        include_pos (str or Set[str]): Remove words whose part-of-speech tag
+            IS NOT included in this param.
+        exclude_pos (str or Set[str]): Remove words whose part-of-speech tag
+            IS in the specified tags.
+        min_freq (int): Remove words that occur in ``doc`` fewer than
+            ``min_freq`` times.
 
     Yields:
-        :class:`spacy.tokens.Token`: the next token from ``doc`` passing specified filters
-        in order of appearance in the document
+        :class:`spacy.tokens.Token`: Next token from ``doc`` passing specified filters
+        in order of appearance in the document.
 
     Raises:
         TypeError: if ``include_pos`` or ``exclude_pos`` is not a str, a set of str,
@@ -340,7 +342,17 @@ def pos_regex_matches(doc, pattern):
     Yields:
         :class:`spacy.tokens.Span`: the next span of consecutive tokens from ``doc`` whose
         parts-of-speech match ``pattern``, in order of apperance
+
+    Warning:
+        *DEPRECATED!* For similar but more powerful and performant functionality,
+        use :func:`textacy.extract.matches()` instead.
     """
+    utils.deprecated(
+        "`pos_regex_matches()` has been deprecated! "
+        "for similar but more powerful and performant functionality, "
+        "use `textacy.extract.matches()` instead.",
+        action="once",
+    )
     # standardize and transform the regular expression pattern...
     pattern = re.sub(r"\s", "", pattern)
     pattern = re.sub(r"<([A-Z]+)\|([A-Z]+)>", r"( (\1|\2))", pattern)
@@ -352,6 +364,131 @@ def pos_regex_matches(doc, pattern):
         yield doc[tags[0 : m.start()].count(" ") : tags[0 : m.end()].count(" ")]
 
 
+def matches(doc, patterns, on_match=None):
+    """
+    Extract ``Span`` s from a ``Doc`` matching one or more patterns
+    of per-token attr:value pairs, with optional quantity qualifiers.
+
+    Args:
+        doc (:class:`spacy.tokens.Doc`)
+        patterns (str or List[str] or List[dict] or List[List[dict]]):
+            One or multiple patterns to match against ``doc``
+            using a :class:`spacy.matcher.Matcher`.
+
+            If List[dict] or List[List[dict]], each pattern is specified
+            as attr: value pairs per token, with optional quantity qualifiers:
+
+            * ``[{"POS": "NOUN"}]`` matches singular or plural nouns,
+              like "friend" or "enemies"
+            * ``[{"POS": "PREP"}, {"POS": "DET", "OP": "?"}, {"POS": "ADJ", "OP": "?"}, {"POS": "NOUN", "OP": "+"}]``
+              matches prepositional phrases, like "in the future" or "from the distant past"
+            * ``[{"IS_DIGIT": True}, {"TAG": "NNS"}]`` matches numbered plural nouns,
+              like "60 seconds" or "2 beers"
+            * ``[{"POS": "PROPN", "OP": "+"}, {}]`` matches proper nouns and
+              whatever word follows them, like "Burton DeWilde yaaasss"
+
+            If str or List[str], each pattern is specified as one or more
+            per-token patterns separated by whitespace where attribute, value,
+            and optional quantity qualifiers are delimited by colons. Note that
+            boolean and integer values have special syntax --- "bool(val)" and
+            "int(val)", respectively --- and that wildcard tokens still need
+            a colon between the (empty) attribute and value strings.
+
+            * ``"POS:NOUN"`` matches singular or plural nouns
+            * ``"POS:PREP POS:DET:? POS:ADJ:? POS:NOUN:+"`` matches prepositional phrases
+            * ``"IS_DIGIT:bool(True) TAG:NNS"`` matches numbered plural nouns
+            * ``"POS:PROPN:+ :"`` matches proper nouns and whatever word follows them
+
+            Also note that these pattern strings don't support spaCy v2.1's
+            "extended" pattern syntax; if you need such complex patterns, it's
+            probably better to use a List[dict] or List[List[dict]], anyway.
+
+        on_match (callable): Callback function to act on matches.
+            Takes the arguments ``matcher``, ``doc``, ``i`` and ``matches``.
+
+    Yields:
+        :class:`spacy.tokens.Span`: Next matching ``Span`` in ``doc``,
+        in order of appearance
+
+    Raises:
+        TypeError
+        ValueError
+
+    See Also:
+        * https://spacy.io/usage/rule-based-matching
+        * https://spacy.io/api/matcher
+    """
+    if isinstance(patterns, compat.unicode_):
+        patterns = [_make_pattern_from_string(patterns)]
+    elif isinstance(patterns, (list, tuple)):
+        if all(isinstance(item, compat.unicode_) for item in patterns):
+            patterns = [_make_pattern_from_string(pattern) for pattern in patterns]
+        elif all(isinstance(item, dict) for item in patterns):
+            patterns = [patterns]
+        elif all(isinstance(item, (list, tuple)) for item in patterns):
+            pass  # already in the right format!
+        else:
+            raise TypeError(
+                "patterns={} is invalid; values must be one of {}".format(
+                    patterns, {"str", "List[str]", "List[dict]", "List[list[dict]]"})
+            )
+    else:
+        raise TypeError(
+            "patterns={} is invalid; values must be one of {}".format(
+                patterns, {"str", "List[str]", "List[dict]", "List[list[dict]]"})
+        )
+    matcher = Matcher(doc.vocab)
+    matcher.add("match", on_match, *patterns)
+    for _, start, end in matcher(doc):
+        yield doc[start:end]
+
+
+def _make_pattern_from_string(patstr):
+    """
+    Args:
+        patstr (str)
+
+    Returns:
+        List[dict]
+    """
+    pattern = []
+    for tokpatstr in constants.RE_MATCHER_TOKPAT_DELIM.split(patstr):
+        parts = tokpatstr.split(":")
+        if 2 <= len(parts) <= 3:
+            attr = parts[0]
+            attr_val = parts[1]
+            if attr and attr_val:
+                # handle special bool and int attribute values
+                special_val = constants.RE_MATCHER_SPECIAL_VAL.match(attr_val)
+                if special_val:
+                    attr_val = eval(special_val.group(0))
+                tokpat = {attr: attr_val}
+            # handle wildcard tokens
+            else:
+                tokpat = {}
+            # handle quantifier ops
+            try:
+                op_val = parts[2]
+                if op_val in constants.MATCHER_VALID_OPS:
+                    tokpat["OP"] = op_val
+                else:
+                    raise ValueError(
+                        "op={} invalid; valid choices are {}".format(
+                            op_val, constants.MATCHER_VALID_OPS)
+                    )
+            except IndexError:
+                pass
+            pattern.append(tokpat)
+        else:
+            raise ValueError(
+                "pattern string '{}' is invalid; "
+                "each element in a pattern string must contain an attribute, "
+                "a corresponding value, and an optional quantity qualifier, "
+                "delimited by colons, like attr:value:op".format(patstr)
+            )
+    return pattern
+
+
 def subject_verb_object_triples(doc):
     """
     Extract an ordered sequence of subject-verb-object (SVO) triples from a
