@@ -10,10 +10,8 @@ import logging
 
 from spacy.tokens import Doc
 
-from . import utils as spacier_utils
 from .. import compat
 from .. import text_stats
-from .. import utils
 
 LOGGER = logging.getLogger(__name__)
 
@@ -113,36 +111,3 @@ class TextStatsComponent(object):
                 )
                 raise
         return doc
-
-
-def merge_entities(doc):
-    """
-    Merge named entities into single tokens in ``doc``, *in-place*.
-
-    Can be used as a stand-alone function, or as part of a spaCy language pipeline::
-
-        >>> spacy_lang = textacy.load_spacy_lang('en')
-        >>> spacy_lang.add_pipe(merge_entities, after='ner')
-        >>> doc = spacy_lang('Burton DeWilde is an entity in this sentence.')
-        >>> doc[0]
-        Burton DeWilde
-
-    Args:
-        doc (:class:`spacy.tokens.Doc`)
-
-    Returns:
-        :class:`spacy.tokens.Doc`: Input ``doc`` with entities merged.
-
-    Warning:
-        *DEPRECATED!* For equivalent functionality, use
-        :func:`spacy.pipeline.functions.merge_entities()` instead.
-        For details, see https://spacy.io/api/pipeline-functions.
-    """
-    utils.deprecated(
-        "`merge_entities()` has been deprecated! for equivalent functionality, "
-        "use :func:`spacy.pipeline.functions.merge_entities()` instead. "
-        "For details, see https://spacy.io/api/pipeline-functions.",
-        action="once",
-    )
-    spacier_utils.merge_spans(doc.ents, doc)
-    return doc
