@@ -9,9 +9,10 @@ from __future__ import absolute_import, division, print_function, unicode_litera
 import logging
 from math import sqrt
 
+from cytoolz import itertoolz
+
 from . import cache
 from . import extract
-from . import utils
 
 LOGGER = logging.getLogger(__name__)
 
@@ -19,7 +20,9 @@ LOGGER = logging.getLogger(__name__)
 class TextStats(object):
     """
     Compute a variety of basic counts and readability statistics for a given
-    document. For example::
+    document. For example:
+
+    .. code-block:: pycon
 
         >>> text = next(textacy.datasets.CapitolWords().texts(limit=1))
         >>> doc = textacy.make_spacy_doc(text)
@@ -87,7 +90,7 @@ class TextStats(object):
 
     def __init__(self, doc):
         self.lang = doc.vocab.lang
-        self.n_sents = sum(1 for _ in doc.sents)
+        self.n_sents = itertoolz.count(doc.sents) if doc.is_sentenced else None
         # get objs for basic count computations
         hyphenator = cache.load_hyphenator(lang=self.lang)
         words = tuple(
@@ -116,13 +119,6 @@ class TextStats(object):
             self.n_syllables, self.n_words, self.n_sents, lang=self.lang
         )
 
-    @property
-    def flesch_readability_ease(self):
-        """For backwards compatibility. Deprecated."""
-        return flesch_readability_ease(
-            self.n_syllables, self.n_words, self.n_sents, lang=self.lang
-        )
-
     @property
     def smog_index(self):
         return smog_index(self.n_polysyllable_words, self.n_sents)
@@ -178,6 +174,12 @@ class TextStats(object):
                 "readability stats can't be computed because doc has 0 words"
             )
             return None
+        elif self.n_sents is None:
+            LOGGER.warning(
+                "readability stats can't be computed because doc has not been "
+                "segmented into sentences"
+            )
+            return None
         return {
             "flesch_kincaid_grade_level": self.flesch_kincaid_grade_level,
             "flesch_reading_ease": self.flesch_reading_ease,
@@ -243,20 +245,6 @@ def flesch_reading_ease(n_syllables, n_words, n_sents, lang=None):
         )
 
 
-def flesch_readability_ease(n_syllables, n_words, n_sents, lang=None):
-    """
-    Alias for :func:`flesch_reading_ease()`, for backwards compatibility.
-
-    Deprecated!
-    """
-    utils.deprecated(
-        "`flesch_readability_ease()` is an alias for `flesch_reading_ease()` "
-        "for backwards compatibility; it will be removed in a future version.",
-        action="once",
-    )
-    return flesch_reading_ease(n_syllables, n_words, n_sents, lang=lang)
-
-
 def smog_index(n_polysyllable_words, n_sents):
     """
     Readability score commonly used in healthcare, whose value estimates the
