@@ -28,8 +28,8 @@ import textacy.extract
 print("import: 'textacy.io'")
 import textacy.io
 
-print("import: 'textacy.keyterms'")
-import textacy.keyterms
+print("import: 'textacy.ke'")
+import textacy.ke
 
 print("import: 'textacy.lang_utils'")
 import textacy.lang_utils
@@ -40,8 +40,8 @@ import textacy.lexicon_methods
 print("import: 'textacy.network'")
 import textacy.network
 
-print("import: 'textacy.preprocess'")
-import textacy.preprocess
+print("import: 'textacy.preprocessing'")
+import textacy.preprocessing
 
 print("import: 'textacy.similarity'")
 import textacy.similarity
